# -*- coding: utf-8 -*-
u"""Утилиты для работы с элементами управления (интерфейсами)."""

import objectpack
from m3_ext.ui import all_components as ext


def anchor100(*elements):
    u"""Установка anchor='100%' для перечня компонент."""
    return list(
        objectpack.ui.anchor100(element)
        for element in elements
    )


def deny_blank(*elements):
    u"""Установка allow_blank=False для перечня компонент."""
    return list(
        objectpack.ui.deny_blank(element)
        for element in elements
    )


def formed(ctl, width=-1, label_width=100, **kwargs):
    u"""Возращает control в контейнере."""
    cont = ext.ExtContainer(layout='form')
    cont.items.append(ctl)
    ctl.anchor = '100%'
    if width > 0:
        cont.width = width
    else:
        cont.flex = -width
    cont.label_width = label_width
    cont.anchor = '100%'
    return objectpack.modify(cont, **kwargs)


class ChoicesFilter(objectpack.filters.CustomFilter):
    u"""Колоночный фильтр с выпадающим списком."""

    def __init__(self, choices, *args, **kwargs):
        u"""Метод инициализации.

        Добавляем значения для выбора и тип компонента.
        """
        self._choices = choices
        kwargs['xtype'] = 'combo'

        super(ChoicesFilter, self).__init__(*args, **kwargs)

    def get_script(self):
        u"""Генерация кода компонента."""
        control = objectpack.ui.make_combo_box(data=list(self._choices))
        control._put_config_value('filterName', self._uid)
        control._put_config_value('tooltip', self._tooltip or control.label)
        control.name = self._uid
        control.allow_blank = True
        control.hide_clear_trigger = False
        control.value = None
        return [control.render()]


class ColumnFilterWithDefaultValue(objectpack.filters.FilterByField):

    def get_script(self):
        control = objectpack.ui._create_control_for_field(
            self.field,
            **self._field_fabric_params
        )
        control._put_config_value('filterName', self._uid)
        control._put_config_value('tooltip', self._tooltip or control.label)
        control.name = self._uid
        control.allow_blank = True
        control.hide_clear_trigger = False
        # Закомментировано, чтобы проставлять значение по-умолчанию
        # control.value = None
        return [control.render()]